[Zope-Checkins] CVS: Zope/lib/python/Zope/Startup - ZctlLib.py:1.1.2.2

Chris McDonough chrism@zope.com
Mon, 13 Jan 2003 12:15:00 -0500


Update of /cvs-repository/Zope/lib/python/Zope/Startup
In directory cvs.zope.org:/tmp/cvs-serv3443/lib/python/Zope/Startup

Modified Files:
      Tag: chrism-install-branch
	ZctlLib.py 
Log Message:
Renamed "zctl" to "zopectl" (as per TODO).


=== Zope/lib/python/Zope/Startup/ZctlLib.py 1.1.2.1 => 1.1.2.2 ===
--- Zope/lib/python/Zope/Startup/ZctlLib.py:1.1.2.1	Sat Jan  4 23:01:37 2003
+++ Zope/lib/python/Zope/Startup/ZctlLib.py	Mon Jan 13 12:14:57 2003
@@ -37,10 +37,10 @@
 
 USAGE = """\
 
-zctl:  Zope appserver controller
+zopectl:  Zope appserver controller
 
 Usage:
-    zctl [-h | --help] [--config=filepath or url]
+    zopectl [-h | --help] [--config=filepath or url]
 
 Options:
     -h or --help       Print this message.  Not compatible with the 'start'
@@ -72,7 +72,7 @@
 """
 
 def start(config_location):
     """ Called by stub zctl.py in an instance_home """
     _ZopeCtlCmd().main(config_location)
 
 class ZopeCtl:
@@ -198,7 +198,7 @@
 
     def shell(self, arg=None):
         """
             Run a command using the system shell.  Commands passed to zctl
             which start with a '!' will also be interpreted by the
             system shell.
 
@@ -537,7 +537,7 @@
     """
         Interactive command processor.
     """
-    def __init__( self, completekey='tab', prompt='zctl> ', verbosity=1 ):
+    def __init__( self, completekey='tab', prompt='zopectl> ', verbosity=1 ):
         if completekey and readline:
             readline.set_completer(self.complete)
             readline.parse_and_bind(completekey + ': complete')
@@ -72,7 +72,7 @@
 
 def start(config_location):
-    """ Called by stub zctl.py in an instance_home """
+    """ Called by stub zopectl.py in an instance_home """
     _ZopeCtlCmd().main(config_location)
 
@@ -198,7 +198,7 @@
     def shell(self, arg=None):
         """
-            Run a command using the system shell.  Commands passed to zctl
+            Run a command using the system shell.  Commands passed to zopectl
             which start with a '!' will also be interpreted by the
             system shell.